@@ -27,6 +27,8 @@ class Client(syst3m.objects.Traceback):
 		private_key=None,
 		# the smart card boolean (optional if client already exists).
 		smartcard=False,
+		# the smart card serial numbers (list) (optional if client already exists).
+		serial_numbers=[],
 		# pass parameters by dict.
 		parameters={},
 	):
@@ -36,7 +38,7 @@ class Client(syst3m.objects.Traceback):
 
 		# parameters by dict.
 		if parameters != {}:
-			alias, username, public_ip, private_ip, public_port, private_port, public_key, private_key, smartcard = Dictionary(parameters).unpack({
+			alias, username, public_ip, private_ip, public_port, private_port, public_key, private_key, smartcard, serial_numbers = Dictionary(parameters).unpack({
 				"alias":None,
 				"username":None,
 				"public_ip":None,
@@ -46,6 +48,7 @@ class Client(syst3m.objects.Traceback):
 				"public_key":None,
 				"private_key":None,
 				"smartcard":False,
+				"serial_numbers":[],
 			})
 
 		# auto fill none & alias exists.
@@ -59,6 +62,7 @@ class Client(syst3m.objects.Traceback):
 			if public_key == None: public_key = response.info["public_key"]
 			if private_key == None: private_key = response.info["private_key"]
 			if smartcard == None: smartcard = response.info["smartcard"]
+			if serial_numbers != []: serial_numbers = response.info["serial_numbers"]
 
 		# objects.
 		self.alias = aliases.Aliases(
@@ -70,7 +74,8 @@ class Client(syst3m.objects.Traceback):
 			private_port=private_port,
 			private_key=private_key,
 			public_key=public_key,
-			smartcard=smartcard, )
+			smartcard=smartcard, 
+			serial_numbers=serial_numbers, )
 		self.agent = agent.Agent(
 			private_key=private_key,
 			public_key=public_key,
@@ -83,8 +88,9 @@ class Client(syst3m.objects.Traceback):
 			alias=alias, )
 		self.ssync = ssync.SSync(
 			alias=alias, )
-		self.smartcard = None
-		if smartcard: self.smartcard = smartcard.SmartCard()
+		self.smartcards = smartcards.SmartCards()
+		for serial_number in serial_numbers:
+			self.smartcards[serial_number] = smartcards.SmartCard(serial_number=serial_number)
 		self.smb = smb.SMB(
 			alias=alias,)
 
@@ -150,7 +156,7 @@ class Client(syst3m.objects.Traceback):
 			"private_port":self.private_port,
 			"private_key":self.private_key,
 			"public_key":self.public_key,
-			"smartcard":self.smartcard,
+			"smartcard:bool,Boolean":self.smartcard,
 		})
 		if not response.success: return response
 
@@ -165,7 +171,7 @@ class Client(syst3m.objects.Traceback):
 				response = self.alias.info()
 				if not response.success: return response
 				info = response.info
-				if self.is_smartcard:
+				if self.smartcard:
 					if info["pin"] in [False, None, "", "none", "None"]:
 						no_passphrase = True
 					else:
@@ -186,6 +192,9 @@ class Client(syst3m.objects.Traceback):
 						passphrase=passphrase,
 						pin=pin,)
 					if not response.success: return response
+				else:
+					response = self.agent.add()
+					if not response.success: return response
 
 		# sync alias.
 		response = self.alias.sync()
@@ -195,6 +204,8 @@ class Client(syst3m.objects.Traceback):
 		return r3sponse.success(f"Successfully checked client [{self.alias_}].")
 
 		#
+	def connect(self):
+		return self.ssh.utils.test(alias=self.alias_)
 	# properties.
 	@property
 	def exists(self):
@@ -256,8 +267,11 @@ class Client(syst3m.objects.Traceback):
 	def public_key(self):
 		return self.alias.public_key
 	@property
-	def is_smartcard(self):
-		return self.smartcard != None
+	def smartcard(self):
+		return self.alias.smartcard
+	@property
+	def serial_numbers(self):
+		return self.alias.serial_numbers
 
 # the initialized clients.
 class Clients(syst3m.objects.Traceback):
@@ -270,11 +284,17 @@ class Clients(syst3m.objects.Traceback):
 		self.__clients__ = {}
 
 		#
+	
 	# initialize.
 	def initialize(self):
 		for alias, info in aliases.aliases.iterate():
 			self[alias] = Client(parameters=info)
+	
 	# iterate.
+	def __iter__(self):
+		return iter(self.__clients__)
+	def list(self):
+		return list(self.__clients__.keys())
 	def iterate(self, clients=[]):
 		if clients == []:
 			clients = list(self.__clients__.keys())
@@ -282,9 +302,8 @@ class Clients(syst3m.objects.Traceback):
 		for i in clients:
 			items.append([i, self.__clients__[i]])
 		return items
-	def __iter__(self):
-		return iter(self.__clients__)
-	# get & set.
+	
+	# get & set client.
 	def __setitem__(self, key, value):
 		if isinstance(key, (int, Integer)):
 			key = list(self.__clients__.keys())[key]
@@ -293,10 +312,90 @@ class Clients(syst3m.objects.Traceback):
 		if isinstance(key, (int, Integer)):
 			key = list(self.__clients__.keys())[key]
 		return self.__clients__[key]
-	# len.
+	
+	# support [>=, <=, <, >] operators.
+	def __gt__(self, clients):
+		if isinstance(clients, int):
+			a=1
+		elif isinstance(clients, self.__class__):
+			clients = len(clients.__clients__)
+		elif not isinstance(clients, self.__class__):
+			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {clients.__class__}.")
+		return len(self.__clients__) > clients
+	def __ge__(self, clients):
+		if isinstance(clients, int):
+			a=1
+		elif isinstance(clients, self.__class__):
+			clients = len(clients.__clients__)
+		elif not isinstance(clients, self.__class__):
+			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {clients.__class__}.")
+		return len(self.__clients__) >= clients
+	def __lt__(self, clients):
+		if isinstance(clients, int):
+			a=1
+		elif isinstance(clients, self.__class__):
+			clients = len(clients.__clients__)
+		elif not isinstance(clients, self.__class__):
+			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {clients.__class__}.")
+		return len(self.__clients__) < clients
+	def __le__(self, clients):
+		if isinstance(clients, int):
+			a=1
+		elif isinstance(clients, self.__class__):
+			clients = len(clients.__clients__)
+		elif not isinstance(clients, self.__class__):
+			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {clients.__class__}.")
+		return len(self.__clients__) <= clients
+
+	# support [==, !=] operators.
+	def __eq__(self, clients):
+		if isinstance(clients, self.__class__):
+			clients = clients.__clients__
+		elif not isinstance(clients, self.__class__):
+			return False
+		return Dictionary(self.__clients__) == Dictionary(clients)
+	def __ne__(self, clients):
+		if isinstance(clients, self.__class__):
+			clients = clients.__clients__
+		elif not isinstance(clients, self.__class__):
+			return True
+		return Dictionary(self.__clients__) != Dictionary(clients)
+
+	# support +.
+	def __concat__(self, clients):
+		if isinstance(clients, self.__class__):
+			clients = clients.__clients__
+		elif not isinstance(value, self.__class__):
+			raise exceptions.FormatError(f"Can not concat object {self.__class__} & {clients.__class__}.")
+		return Dictionary(self.__clients__) + Dictionary(clients)
+
+	# support 'in' operator.
+	def __contains__(self, client):
+		if isinstance(client, (list, Files.Array)):
+			for i in client:
+				if str(i) in list(self.__clients__.keys()):
+					return True
+			return False
+		else:
+			return str(client) in list(self.__clients__.keys())
+		#
+	
+	# representations.
+	def __repr__(self):
+		return str(self)
+	def __str__(self):
+		return str(self.__clients__)
+	def __int__(self):
+		return int(self.__clients__)
+	def __float__(self):
+		return float(self.__clients__)
+	def __bool__(self):
+		return len(self.__clients__) > 0
 	def __len__(self):
 		return len(self.__clients__)
 
+	#
+
 # initialized objects.
 clients = Clients()
 clients.initialize()
