@@ -24,10 +24,7 @@ try:
 # download.
 except ImportError as e:
 	import os
-	if os.path.exists("/usr/bin/pip3"): 
-		os.system(f"/usr/bin/pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.pip --user {os.environ.get('syst3m.defaults.vars.user')}")
-	else:
-		os.system(f"pip3 install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.pip")
+	os.system(f"python3 -m pip install -r {syst3m.defaults.source_path(__file__, back=3)}/requirements/requirements.pip")
 
 	# imports.
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, pexpect, random, getpass, time
@@ -61,7 +58,7 @@ if syst3m.defaults.options.log_level >= 1:
 # database.
 DATABASE = Directory(path=syst3m.env.get_string("SSHT00LS_DATABASE", default=f"{syst3m.defaults.vars.home}/.{ALIAS}"))
 if not DATABASE.fp.exists():
-	r3sponse.log(f"{syst3m.color.orange}Root permission{syst3m.color.end} required to create ssht00ls database [{DATABASE}].")
+	r3sponse.log(f"{syst3m.color.orange}Root permission{syst3m.color.end} required to create {ALIAS} database [{DATABASE}].")
 	os.system(f" sudo mkdir -p {DATABASE}")
 	Files.chown(str(DATABASE), owner=syst3m.defaults.vars.owner, group=syst3m.defaults.vars.group, sudo=True, recursive=True)
 	Files.chmod(str(DATABASE), permission=700, sudo=True, recursive=True)
@@ -110,7 +107,7 @@ if CHECKS and not RESET_CACHE:
 	# check lib.
 	if not Files.exists(f"{SOURCE_PATH}/lib") or cl1.argument_present("--download-lib"):
 		r3sponse.log("Downloading the ssht00ls library.")
-		os.system(f"rm -fr /tmp/ssht00ls && git clone https://github.com/vandenberghinc/ssht00ls /tmp/ssht00ls && rsync -azq /tmp/ssht00ls/ssht00ls/lib/ {Files.join(SOURCE_PATH, 'lib/')}")
+		os.system(f"rm -fr /tmp/ssht00ls && git clone -q https://github.com/vandenberghinc/ssht00ls /tmp/ssht00ls && rsync -azq /tmp/ssht00ls/ssht00ls/lib/ {Files.join(SOURCE_PATH, 'lib/')}")
 		if cl1.argument_present("--download-lib"): sys.exit(0)
 
 	# check usr lib.
