@@ -38,7 +38,7 @@ class Keys(syst3m.objects.Traceback):
 		path = Formats.denitialize(path)
 		old = Formats.denitialize(old)
 		new = Formats.denitialize(new)
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"old":old,
 			"new":new,
 			"path":path,
@@ -79,7 +79,7 @@ class Keys(syst3m.objects.Traceback):
 		path = Formats.denitialize(path)
 		passphrase = Formats.denitialize(passphrase)
 		comment = Formats.denitialize(comment)
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"old":old,
 			"passphrase":passphrase,
 			"comment":comment,
@@ -121,7 +121,7 @@ class Keys(syst3m.objects.Traceback):
 		passphrase = Formats.denitialize(passphrase)
 		comment = Formats.denitialize(comment)
 		if directory[len(directory)-1] != "/": directory += "/"
-		response = r3sponse.check_parameters({
+		response = r3sponse.parameters.check({
 			"path":directory,
 		}, traceback=self.__traceback__(function="generate"))
 		if not response["success"]: return response
@@ -131,11 +131,11 @@ class Keys(syst3m.objects.Traceback):
 			passphrase = '""'
 
 		# create dir.
-		if Files.exists(f"{directory}/public_key"): 
+		if directory != None and Files.exists(f"{directory}/public_key"): 
 			return r3sponse.error(f"Public key [{directory}/public_key] already exists.")
-		elif Files.exists(f"{directory}/private_key"): 
+		elif directory != None and Files.exists(f"{directory}/private_key"): 
 			return r3sponse.error(f"Private key [{directory}/private_key] already exists.")
-		elif not Files.exists(directory): 
+		elif directory != None and not Files.exists(directory): 
 			os.mkdir(directory)
 			Files.chmod(path=directory, permission=700, sudo=True)
 			Files.chown(path=directory, owner=syst3m.defaults.vars.user, group=None, sudo=True)
