@@ -30,17 +30,34 @@ class SmartCards(syst3m.objects.Traceback):
 				if Files.exists(path):
 					self.path = path
 					break
-			if self.path == None: raise ValueError("Unable to locate opensc-pkcs11.so path.")
+			if self.path == None: raise ValueError("Unable to locate opensc-pkcs11.so.")
 					
 		elif syst3m.defaults.vars.os in ["macos"]: 
+			self.original_path = None
+			for path in [
+				"/usr/local/lib/libykcs11.dylib",
+			]:
+				if Files.exists(path):
+					self.original_path = path
+					break
+			if self.original_path == None: r3sponse.log("&ORANGE&Unable to locate libykcs11.dylib.&END&")
+
 			#self.original_path = "/usr/local/lib/libykcs11.dylib"
 			#self.path = "/usr/local/lib/libykcs11_NOTALNK.dylib"
 			#self.original_path = "/usr/local/lib/opensc-pkcs11.so"
-			self.original_path = f"{SOURCE_PATH}/lib/opensc/macos/opensc-pkcs11.so"
-			self.path = "/usr/local/lib/opensc-pkcs11_NOTALINK.so"
-			if not Files.exists(self.original_path):
-				raise OSError("opensc package is not installed, run: [$ brew install yubico-piv-tool opensc].")
+			#self.original_path = f"{SOURCE_PATH}/lib/opensc/macos/opensc-pkcs11.so"
+			#self.path = "/usr/local/lib/opensc-pkcs11_NOTALINK.so"
+			self.original_path = path
+			self.path = "/usr/local/lib/libykcs11_NOTALNK.dylib"
+			#if not Files.exists(self.original_path):
+			#	r3sponse.log("&RED&OpenSC package is not installed&END&, run: [$ brew install yubico-piv-tool opensc].")
 
+		# attributes.
+		self.__smartcards__ = {}
+
+		#
+
+	# functions.
 	def scan(self, silent=False):
 
 		# list.
@@ -78,6 +95,7 @@ class SmartCards(syst3m.objects.Traceback):
 		})
 
 		#
+	
 	# system functions.
 	def __single_key_plugged_in__(self):
 
@@ -98,6 +116,106 @@ class SmartCards(syst3m.objects.Traceback):
 			"smartcard":l_response["smartcards"][list(l_response["smartcards"].keys())[0]],
 		})
 
+	# iterate.
+	def __iter__(self):
+		return iter(self.__smartcards__)
+	def list(self):
+		return list(self.__smartcards__.keys())
+	def iterate(self):
+		return self.__smartcards__.items()	
+
+	# get & set client.
+	def __getitem__(self, key):
+		return self.__smartcards__[str(key)]
+		#
+	def __setitem__(self, key, value):
+		self.__smartcards__[str(key)] = value
+		#
+
+	# support [>=, <=, <, >] operators.
+	def __gt__(self, smartcards):
+		if isinstance(smartcards, int):
+			a=1
+		elif isinstance(smartcards, self.__class__):
+			smartcards = len(smartcards.__smartcards__)
+		elif not isinstance(smartcards, self.__class__):
+			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {smartcards.__class__}.")
+		return len(self.__smartcards__) > smartcards
+	def __ge__(self, smartcards):
+		if isinstance(smartcards, int):
+			a=1
+		elif isinstance(smartcards, self.__class__):
+			smartcards = len(smartcards.__smartcards__)
+		elif not isinstance(smartcards, self.__class__):
+			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {smartcards.__class__}.")
+		return len(self.__smartcards__) >= smartcards
+	def __lt__(self, smartcards):
+		if isinstance(smartcards, int):
+			a=1
+		elif isinstance(smartcards, self.__class__):
+			smartcards = len(smartcards.__smartcards__)
+		elif not isinstance(smartcards, self.__class__):
+			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {smartcards.__class__}.")
+		return len(self.__smartcards__) < smartcards
+	def __le__(self, smartcards):
+		if isinstance(smartcards, int):
+			a=1
+		elif isinstance(smartcards, self.__class__):
+			smartcards = len(smartcards.__smartcards__)
+		elif not isinstance(smartcards, self.__class__):
+			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {smartcards.__class__}.")
+		return len(self.__smartcards__) <= smartcards
+
+	# support [==, !=] operators.
+	def __eq__(self, smartcards):
+		if isinstance(smartcards, self.__class__):
+			smartcards = smartcards.__smartcards__
+		elif not isinstance(smartcards, self.__class__):
+			return False
+		return Dictionary(self.__smartcards__) == Dictionary(smartcards)
+	def __ne__(self, smartcards):
+		if isinstance(smartcards, self.__class__):
+			smartcards = smartcards.__smartcards__
+		elif not isinstance(smartcards, self.__class__):
+			return True
+		return Dictionary(self.__smartcards__) != Dictionary(smartcards)
+
+	# support +.
+	def __concat__(self, smartcards):
+		if isinstance(smartcards, self.__class__):
+			smartcards = smartcards.__smartcards__
+		elif not isinstance(value, self.__class__):
+			raise exceptions.FormatError(f"Can not concat object {self.__class__} & {smartcards.__class__}.")
+		return Dictionary(self.__smartcards__) + Dictionary(smartcards)
+
+	# support 'in' operator.
+	def __contains__(self, smartcard):
+		if isinstance(smartcard, (list, Files.Array)):
+			for i in smartcard:
+				if str(i) in list(self.__smartcards__.keys()):
+					return True
+			return False
+		else:
+			return str(smartcard) in list(self.__smartcards__.keys())
+		#
+	
+	# representations.
+	def __repr__(self):
+		return str(self)
+	def __str__(self):
+		return str(self.__smartcards__)
+	def __int__(self):
+		return int(self.__smartcards__)
+	def __float__(self):
+		return float(self.__smartcards__)
+	def __bool__(self):
+		return len(self.__smartcards__) > 0
+	def __len__(self):
+		return len(self.__smartcards__)
+	
+	#
+
+
 # the smart card class.
 class SmartCard(syst3m.objects.Traceback):
 	# the smart card is by default a YubiKey 5 NFC
@@ -161,8 +279,8 @@ class SmartCard(syst3m.objects.Traceback):
 	):
 		
 		# check params.
-		response = r3sponse.check_parameters(
-			empty_value=None,
+		response = r3sponse.parameters.check(
+			default=None,
 			traceback=self.__traceback__(function="unblock_pin"),
 			parameters={
 				"pin":pin,
@@ -193,8 +311,8 @@ class SmartCard(syst3m.objects.Traceback):
 	):
 
 		# check params.
-		response = r3sponse.check_parameters(
-			empty_value=None,
+		response = r3sponse.parameters.check(
+			default=None,
 			traceback=self.__traceback__(function="change_pin"),
 			parameters={
 				"new":new,
@@ -227,8 +345,8 @@ class SmartCard(syst3m.objects.Traceback):
 	):
 
 		# check params.
-		response = r3sponse.check_parameters(
-			empty_value=None,
+		response = r3sponse.parameters.check(
+			default=None,
 			traceback=self.__traceback__(function="change_puk"),
 			parameters={
 				"new":new,
@@ -260,8 +378,8 @@ class SmartCard(syst3m.objects.Traceback):
 	):
 
 		# check params.
-		response = r3sponse.check_parameters(
-			empty_value=None,
+		response = r3sponse.parameters.check(
+			default=None,
 			traceback=self.__traceback__(function="generate_key"),
 			parameters={
 				"pin":pin,
@@ -298,8 +416,8 @@ class SmartCard(syst3m.objects.Traceback):
 	):
 
 		# check params.
-		response = r3sponse.check_parameters(
-			empty_value=None,
+		response = r3sponse.parameters.check(
+			default=None,
 			traceback=self.__traceback__(function="generate_management_key"),
 			parameters={
 				"pin":pin,
@@ -499,6 +617,12 @@ class SmartCard(syst3m.objects.Traceback):
 
 		#
 
+	# properties.
+	@property
+	def activated(self):
+		raise ValueError("Coming soon.")
+		return False
+
 	# system functions.
 	def __handle_default_output__(self, output):
 
@@ -523,6 +647,16 @@ class SmartCard(syst3m.objects.Traceback):
 		# success.
 		return r3sponse.success("Successfully checked the output.")
 
+	# representations.
+	def __repr__(self):
+		return str(self)
+	def __str__(self):
+		return str(self.serial_number)
+	def __int__(self):
+		return int(self.serial_number)
+	def __float__(self):
+		return float(self.serial_number)
+	#
 
 # initialized classes.
 smartcards = SmartCards()
