@@ -42,8 +42,9 @@ def execute(
 
 	# execute.
 	if log_level >= 6: print(command)
-	if loader != None:
+	if loader != None and log_level >= 0:
 		loader = syst3m.console.Loader(loader, interactive=INTERACTIVE)
+	else: loader = None
 	
 	# script.
 
@@ -67,6 +68,7 @@ def execute(
 	try:
 		proc = subprocess.run(
 		    ["sh", path],
+		    stdin=subprocess.PIPE,
 			check=True,
 			capture_output=True,
 			text=True,
@@ -120,7 +122,7 @@ def execute(
 
 # test ssh functions.
 def test(alias=None, accept_new_host_keys=True, checks=True):
-	accept_new_host_keys = Boolean(accept_new_host_keys).convert(true="printf 'yes' | ", false="")
+	accept_new_host_keys = Boolean(accept_new_host_keys).string(true="printf 'yes' | ", false="")
 	output = syst3m.utils.__execute_script__(f"""{accept_new_host_keys}ssh {DEFAULT_SSH_OPTIONS} {alias} ' echo "Hello World" ' """)
 	response = check_errors(output)
 	if not response.success:
@@ -212,10 +214,12 @@ def ssh_agent():
 	os.environ["SSH_AGENT_PID"] = SSH_AGENT_PID
 
 # kill all ssh procs with that includes the identifier.
-def kill(identifier=None, sudo=False, dont_kill=["grep", "ssht00ls"]):
-	response = r3sponse.check_parameters({
+def kill(identifier=None, sudo=False):
+	response = r3sponse.parameters.check({
 		"identifier:str":identifier,})
 	if not response.success: return response
+	return syst3m.defaults.kill(includes=identifier, sudo=sudo)
+	# old.
 	killed = 0
 	output = syst3m.utils.__execute_script__(f"""ps -ax | grep "{identifier}" | """ + """awk '{print $1"|"$2"|"$3"|"$4}' """)
 	for line in output.split("\n"):
