@@ -30,7 +30,7 @@ class SSync(syst3m.objects.Traceback):
 		self.daemons = daemons
 		
 		#
-	def index(self, path=None, alias=None, log_level=0, checks=True, accept_new_host_keys=True):
+	def index(self, path=None, alias=None, log_level=syst3m.defaults.options.log_level, checks=True, accept_new_host_keys=True):
 
 		# check specific.
 		if self.specific:
@@ -167,7 +167,7 @@ class SSync(syst3m.objects.Traceback):
 		# checks.
 		checks=True,
 		# log level.
-		log_level=0,
+		log_level=syst3m.defaults.options.log_level,
 		# get the command in str.
 		command=False,
 	):	
@@ -249,7 +249,7 @@ class SSync(syst3m.objects.Traceback):
 		checks=True,
 		check_base=True,
 		# log level.
-		log_level=0,
+		log_level=syst3m.defaults.options.log_level,
 		# get the command in str.
 		command=False,
 	):
@@ -273,11 +273,16 @@ class SSync(syst3m.objects.Traceback):
 					if "is not added to the" not in response.error: return response
 					else:
 						if CONFIG["aliases"][alias]["smartcard"] in [True, "true", "True"]:
-							response = encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+							response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["pin"])
+							if not response["success"]: return response
+							passphrase = response.decrypted.decode()
 						else:
-							response = encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
-						if not response["success"]: return response
-						passphrase = response.decrypted.decode()
+							if CONFIG["aliases"][alias]["passphrase"] not in ["", False]:
+								response = encryption.encryption.decrypt(CONFIG["aliases"][alias]["passphrase"])
+								if not response["success"]: return response
+								passphrase = response.decrypted.decode()
+							else:
+								passphrase = None
 						response = agent.add(private_key=CONFIG["aliases"][alias]["private_key"], passphrase=passphrase)
 						if not response["success"]: return response
 				if self.specific: self.activated = True
@@ -323,7 +328,7 @@ class SSync(syst3m.objects.Traceback):
 		# accept new host verification keys.
 		accept_new_host_keys=True,
 		# log level.
-		log_level=0,
+		log_level=syst3m.defaults.options.log_level,
 		# the daemon mode.
 		mode="mount",
 	):
@@ -336,7 +341,7 @@ class SSync(syst3m.objects.Traceback):
 			if alias == None: alias = self.alias
 
 		# checks.
-		response = r3sponse.check_parameters(
+		response = r3sponse.parameters.check(
 			traceback=self.__traceback__(function="mount"), 
 			parameters={
 				"path:str":path,
@@ -415,14 +420,14 @@ class SSync(syst3m.objects.Traceback):
 		# sudo required.
 		sudo=False,
 		# log level.
-		log_level=0,
+		log_level=syst3m.defaults.options.log_level,
 	):
 
 		# depricated.
 		return r3sponse.error("DEPRICATED.")
 
 		# checks.
-		response = r3sponse.check_parameters(
+		response = r3sponse.parameters.check(
 			traceback=self.__traceback__(function="unmount"), 
 			parameters={
 				"path:str":path,
